==> ?f=plg_jw_allvideos-v4.7.0_j1.5-3.x.zip: README.md <==
AllVideos
=========

AllVideos (by JoomlaWorks) is truly THE all-in-one media management solution for Joomla and a classic must-have extension for any Joomla based website.

You can use the plugin to easily embed media hosted on popular services like YouTube, Vimeo, Dailymotion, SoundCloud (and many more) inside your Joomla articles (or K2, redShop, Virtuemart etc).

Additionally, it allows you to playback almost any video/audio file format hosted on your server or even a remote server, providing great flexibility when it comes to media content embedding. Fun videos, product presentations, audio podcasts, you name it!


## WHY ALLVIDEOS?
- You don't have to copy/paste huge blocks of HTML code, just to get a video from YouTube to playback on your Joomla website! Your WYSIWYG editor loves it and so will you and your clients!
- You use simple and descriptive plugin tags like {youtube}heu37ej3qs{/youtube}, {flv}batman_darknight{/flv} or {mp3}pixies_bonemachine{/mp3}.
- Allows for mobile/tablet compatible media embedding where supported.

AllVideos means dead-simple & inexpensive media streaming for anyone. You can use, for example, YouTube to upload your videos and then embed them inside your site without consuming your server's bandwidth or having to spend money on expensive video conversion software!


## FEATURES
1. Dozens of media providers supported like YouTube, Vimeo, Dailymotion, Metacafe, MySpace, Flickr Video, Blip.tv, TwitVid, yFrog, SoundCloud & more.
2. Stream your own media content, using the 20+ web compatible video and audio formats like flv, swf, mov, mp4, wmv, wma, mp3, 3gp, webm, ogv, ogg, divx and more.
3. Easily embed your media content either directly from your server or a remote server!
4. Simple controls inside the plugin's parameters page provide layout consistency on all the videos shown in your Joomla website. Set your preferences in seconds, publish the plugin and you're ready to start streaming content!
5. Easy, descriptive syntax for media embedding - {format/provider}filename{/format/provider}. You can also use syntax like {format/provider}filename|width|height|autoplay{/format/provider} (e.g. an "autoplaying" {youtube}he73js82|600|450|1{/youtube}) to display videos at different dimensions!
6. Uses MVC templating. Just copy the /tmpl folder included in the plugin, move it to your template's /html folder and rename it to "jw_allvideos", then style the output as you wish.
7. Mobile/tablet friendly: if you use MP4 for uploaded videos or if you use services like YouTube, Vimeo & Dailymotion, your videos are mobile ready.
8. Includes 3 templates: Classic, Framed and Responsive
9. Fully responsive players when using the "Responsive" template.
10. Uses the core Joomla updater (since version 4.5.0).


## COMPATIBILITY
AllVideos is fully compatible with Joomla versions 1.5, 2.5 & 3.x


## LEARN MORE
Visit the AllVideos product page at: http://www.joomlaworks.net/allvideos

==> ?f=plg_jw_allvideos-v4.8.0_j1.5-3.x.zip: README.md <==
AllVideos
=========

AllVideos (by JoomlaWorks) is truly THE all-in-one media management solution for Joomla and a classic must-have extension for any Joomla based website.

You can use the plugin to easily embed media hosted on popular services like YouTube, Vimeo, Dailymotion, SoundCloud (and many more) inside your Joomla articles (or K2, redShop, Virtuemart etc).

Additionally, it allows you to playback almost any video/audio file format hosted on your server or even a remote server, providing great flexibility when it comes to media content embedding. Fun videos, product presentations, audio podcasts, you name it!


## WHY ALLVIDEOS?
- You don't have to copy/paste huge blocks of HTML code, just to get a video from YouTube to playback on your Joomla website! Your WYSIWYG editor loves it and so will you and your clients!
- You use simple and descriptive plugin tags like {youtube}http://www.youtube.com/watch?v=g5lGNkS5TE0{/youtube} (or just {youtube}g5lGNkS5TE0{/youtube}), {flv}batman_darknight{/flv} or {mp3}pixies_bonemachine{/mp3}.
- Allows for mobile/tablet compatible media embedding where supported.

AllVideos means dead-simple & inexpensive media streaming for anyone. You can use, for example, YouTube to upload your videos and then embed them inside your site without consuming your server's bandwidth or having to spend money on expensive video conversion software!


## FEATURES
1. Dozens of media providers supported like YouTube (videos & playlists), Vimeo, Dailymotion, Facebook Videos, SoundCloud, MySpace, Flickr Videos, Yahoo, Twitch, Ustream, Funny Or Die, Vine & more.
2. Stream your own media content, using the 20+ web compatible video and audio formats like flv, swf, mov, mp4, wmv, wma, mp3, 3gp, webm, ogv, ogg, divx and more.
3. Easily embed your media content either directly from your server or a remote server!
4. Simple controls inside the plugin's parameters page provide layout consistency on all the videos shown in your Joomla website. Set your preferences in seconds, publish the plugin and you're ready to start streaming content!
5. Easy, descriptive syntax for media embedding - {format/provider}filename{/format/provider}. You can also use syntax like {format/provider}filename|width|height|autoplay{/format/provider} (e.g. an "autoplaying" {youtube}he73js82|600|450|1{/youtube}) to display videos at different dimensions!
6. Uses MVC templating. Just copy the /tmpl folder included in the plugin, move it to your template's /html folder and rename it to "jw_allvideos", then style the output as you wish.
7. Mobile/tablet friendly: if you use MP4 for uploaded videos or if you use services like YouTube, Vimeo & Dailymotion, your videos are mobile ready.
8. Includes 3 templates: Classic, Framed and Responsive
9. Fully responsive players when using the "Responsive" template.
10. Uses the core Joomla updater (since version 4.5.0).


## COMPATIBILITY
AllVideos is fully compatible with Joomla versions 1.5, 2.5 & 3.x


## LEARN MORE
Visit the AllVideos product page at: http://www.joomlaworks.net/allvideos
